<?php

require_once 'includes/classes/cronjob/CronjobTask.interface.php';

class RecycleCronJob implements CronjobTask
{
	function run()
	{
		global $resource, $pricelist;
		
		$where	= 'fleet_mission = :mission AND fleet_mess = :mess';
		
		$sql = 'SELECT DISTINCT fleet.*, ownuser.username as own_username, targetuser.username as target_username,
		ownplanet.name as own_planetname, targetplanet.name as target_planetname, targetplanet.der_metal as der_metal, targetplanet.der_crystal as der_crystal
		FROM %%FLEETS%% fleet
		LEFT JOIN %%USERS%% ownuser ON (ownuser.id = fleet.fleet_owner)
		LEFT JOIN %%USERS%% targetuser ON (targetuser.id = fleet.fleet_target_owner)
		LEFT JOIN %%PLANETS%% ownplanet ON (ownplanet.id = fleet.fleet_start_id)
		LEFT JOIN %%PLANETS%% targetplanet ON (targetplanet.id = fleet.fleet_end_id)
		WHERE '.$where.' ORDER BY fleet.fleet_start_time;';
		
		
		$param = array(
			':mission'	=> 8,
			':mess'	=> 2
		);
		
		$fleetResult = Database::get()->select($sql, $param);
		
		$planets = array();
		$fleets = array();
		
		foreach($fleetResult as $fleetRow){
			if(!isset($planets[$fleetRow['fleet_end_id']]))$planets[$fleetRow['fleet_end_id']] = array();
			
			$planets[$fleetRow['fleet_end_id']][] = $fleetRow['fleet_id'];
			$fleets[$fleetRow['fleet_id']] = $fleetRow;
		}
		
		foreach($planets as $id => $pl){
			$fletsOnPlanet = count($pl);
			
			$minusMetal 	= 0;
			$minusCrystal 	= 0;
			
			foreach($pl as $flId){
				
				$fleet = $fleets[$flId];
				
				$derMetal 	= max(0,$fleet['der_metal']-$minusMetal);
				$derCrystal = max(0,$fleet['der_crystal']-$minusCrystal);
				$recTime 	= $fleet['fleet_rec_time']?$fleet['fleet_rec_time']:$fleet['fleet_start_time'];
				$sql				= 'SELECT * FROM %%USERS%% WHERE id = :userId;';
				$recUser			= Database::get()->selectSingle($sql, array(
						':userId'	=> $fleet['fleet_owner']
				));

				$recUserFactors	= getFactors($recUser);
				$shipStorageFactor	= 1 + $recUserFactors['ShipStorage'];
				
				if(($derMetal+$derCrystal)>0 && ($recTime+60)<TIMESTAMP){
					$FleetRec		= explode(';', $fleet['fleet_array']);
					
					$recyclerStorage	= 0;
					$recyclerPerMin		= 0;
					
					foreach($FleetRec as $Item => $Group)
					{
						if (empty($Group))
							continue;
						
						$Ship    = explode(',', $Group);
						
						if ($Ship[0] == 209 ||  $Ship[0] == 219)
						{
							$recyclerStorage   += $pricelist[$Ship[0]]['capacity'] * $Ship[1];
							$recyclerPerMin	   += floor($pricelist[$Ship[0]]['capacity']/60) * $Ship[1];
						}

					}
					
					$recyclerStorage   *= $shipStorageFactor;
					
					
					$mins = floor((TIMESTAMP-$recTime)/60);
					
					$met = floor($recyclerPerMin/2)*$mins;
					$cry = floor($recyclerPerMin/2)*$mins;
					$rMetal = 0;
					$rCrystal = 0;
					
					if($met>$derMetal){
						$rMetal = max(0,$met-$derMetal);
					}
					if($cry>$derCrystal){
						$rCrystal = max(0,$cry-$derCrystal);
					}
					
					$recAvailStorage = $recyclerStorage-($fleet['fleet_resource_metal']+$fleet['fleet_resource_crystal']);
					
					if($recAvailStorage > min($met+$rCrystal,$derMetal)){
						$mMetal 	= min($met+$rCrystal,$derMetal);
						
						$recAvailStorage -= $mMetal;
					}else{
						$mMetal 	= $recAvailStorage;
						
						$recAvailStorage = 0;
					}
					
					if($recAvailStorage > min($cry+$rMetal,$derCrystal)){
						$mCrystal 	= min($cry+$rMetal,$derCrystal);
						
						$recAvailStorage -= $mCrystal;
					}else{
						$mCrystal 	= $recAvailStorage;
						
						$recAvailStorage = 0;
					}
					
					
					$minusMetal		+= $mMetal;
					$minusCrystal 	+= $mCrystal;
					
					$time = $recTime+$mins*60;
					
					
					
					$resparam	= array();
					$ressql = "UPDATE %%FLEETS%% as f,%%PLANETS%% as p SET 
					f.fleet_resource_metal 		= f.fleet_resource_metal + ".$mMetal.", 
					f.fleet_resource_crystal 	= f.fleet_resource_crystal + ".$mCrystal.",
					f.fleet_rec_time			= ".$time.",
					p.der_metal					= p.der_metal - ".$mMetal.", 
					p.der_crystal				= p.der_crystal - ".$mCrystal."
					WHERE f.fleet_id = :fleetId AND p.id = :planetId;";
					$resparam[':fleetId']	= $fleet['fleet_id'];
					$resparam[':planetId']	= $fleet['fleet_end_id'];
					Database::get()->update($ressql, $resparam);
				}
			}
		}
	}
}
?>